--------------------------------------------------------------------------------
-- Copyright  2021								|
-- All Rights Reserved.								|
-- 										|
-- Permission to use, copy, modify, and distribute this software in any way	|
-- is not granted without expressed written agreement. This copyright applies	|
-- to the all code, data and artwork related to this project and all associated	|
-- projects published by the author.						|
--										|
-- More information on copyright is available from sources on-line.		|
-- Use an actual factual one!							|
--------------------------------------------------------------------------------

local AddonName, NS = ...

local format = string.format
local OptionsLoaded
----------------------------------
--  Initialise Localisations    --
----------------------------------
NS.readmeta = {
	__index = function(self, key)
		rawset(self, key, key)
		if FIZZLEDEBUG then
			geterrorhandler()(AddonName..": "..self._metaError.."'"..tostring(key).."'")
		end
		return key
	end
}

NS.TEXTS = setmetatable({}, NS.readmeta)
NS.TEXTS._metaError = GetLocale() .. ": Locale key  missing L."
NS.TEXTS.Error = "ERROR!"
NS.TEXTS.AddonHighlight = "|cffff8200"..AddonName.."|r"
function NS.TEXTS.print(...)
	print(NS.TEXTS.AddonHighlight, "|cffff0000"..NS.TEXTS.Error.."|r\n", ...)
end

NS.TEXTS.GetText = function(text, value, ...)
	if not value then value = "" end
	return format(text, value, ...)
end

local L = NS.TEXTS

--------------------------------------------------------------------------------------------------
--                                      Start Localisation                                      --
--------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------
--			Text Removed From Spell/Item Names in the Context Menu list		--
--------------------------------------------------------------------------------------------------
L.ContextRemove = {
	Teleport = "Teleport: ",
	Portal = "Portal: ",
	Hearthstone = "Hearthstone",
}

--------------------------------------------------------------------------------------------------
--    %s entries are replaced variables in-game

--    L.Durability = "Armor %s%%" = Armor 80%
--    L.Durability = "%s%% of Armor" = 80% of Armor
--------------------------------------------------------------------------------------------------
L.AbrevHour = "h"
L.AbrevMinute = "m"
L.AbrevSecond = "s"
L.AccessoryNoDefault = "No default accessory available for:"
L.AccessoryNotEnabled = "Accessory not enabled for this character:"
L.AccessoryNotFound = "Accessory %s not found:"
L.AccessoryNotLoaded = "Accessory did not load:"
L.AccessorySettings = "Accessory settings did not return a table:"
L.Addon = "AddOn"
L.AddonConfig = "Click to configure global settings for this addon"
L.Addons = ADDONS
L.Addons2 = ADDONS .. " 2"
L.AFK = DEFAULT_AFK_MESSAGE
L.AFKTip = "Record important messages while AFK"
L.Alpha = "Alpha"
L.AM = "%s am"

L.BadAutoBar = "AutoBar has not loaded it's BasciDriver. Please re-log and try this operation again!"
L.BadParameter = "Bad %s parameter supplied to %s: %s"
L.Background = BACKGROUND
L.BackgroundColors = "%s %s"
L.BossFrames = "Boss Frames"
L.BossOvleray = strupper(BOSS) .. " 1 - 5"
L.BottomRight = "Bottom Right"
L.Button = "Button"
L.ByClass = "by class"

L.Cancel = CANCEL
L.Change = COMMUNITIES_CREATE_DIALOG_ICON_SELECTION_BUTTON
L.Channels = CHANNELS
L.ChannelAdd = "Add Channel: %s"
L.CharacterConfig = "Click to configure character settings only for this addon"
L.Characters = "Characters"
L.Chat = CHAT
L.ChatBarHide = "Bar"
L.ChatBarHideTip = "On: Show always\nOff: When mouse is over"
L.ChatButtonOrderTip = "Chat button display order"
L.ChatChannelNewTip = "Create a new chat channel"
L.ChatFontSizeTip = "Chat frame font size"
L.ChatGroups = "Chat Groups"
L.ChatManagedTip = "Add to chat button bar"
L.ChatNameTip = "Chat channel name"
L.Clear = "Clear"
L.Colors = COLORS
L.Combat = COMBAT
L.CombatColorsTip = "Change color in combat"
L.CombatLog = COMBAT_LOG
L.ContextMenu = "Context Menu"
L.ColorPickerTip = "Left Click: Set\nRight Click: Default"
L.ConfirmDelete = "Confirm Delete"
L.ConfirmDeleteTip = "Enforce typing 'DELETE' to perform, certain actions"
L.ConfirmReload = "Save settings and reload the UI?"
L.ConfirmReset = "Reset character to default settings?"
L.Copy = "Copy"
--L.CopySettings = "Copy Settings"
L.Critical = "Critical"
L.Cursor = "Cursor"

L.Daily = DAILY
L.Damage = DAMAGE
L.DeathKnightRunes = "DK Runes"
L.Dead = strupper(DEAD)
L.Defaults = DEFAULTS
L.Delete = DELETE
L.DeleteChannel = "Remove channel from use"
L.DragonFlightReset = "Dragonflight!"
L.Disconnected = "DISCONNECTED"
L.Disabled = ADDON_DISABLED
L.DisabledInCombat = "Disabled in combat!"
L.Durability = "Armor %s%%"

L.EagleEye = "Eagle Eye"
L.Edit = EDIT
L.EditFontSizeTip = "Chat edit box font size"
L.Empty = "Empty!"
L.Enable = ENABLE
L.Enabled = VIDEO_OPTIONS_ENABLED
L.EnabledTip = "Enable the %s"
L.ErrorLoadOptions = "Options failed to load: %s"
L.ErrorNoAddonSettings = "No settings for addon %s. Please reset FauxMazzle!"
L.Excluded = "Excluded"

L.Find = "Find"
L.Fixed = "Fixed"
L.Font = "Font"
L.FontSize = "Font Size"
L.FontTip = "Font to use for chat frames"
L.FPS = "%s fps" -- Frames Per Second
L.Full = LOC_TYPE_FULL

L.Game = GAME
L.General = GENERAL
L.GlobalSettings = "Settings effect all characters!"
L.GoldOnly = "Gold Only @"
L.GoldOnlyTip = "Suppress silver and copper display once you reach this much gold"
L.Group = GROUP
L.Guild = GUILD
L.GuildChatTip = "Show/Hide Guild button on joining/leaving"

L.Healer = HEALER
L.Health = HEALTH
L.Highlight = "Highlight"
L.History = HISTORY
L.HistoryTip = "Messages from last session"
L.HistoryWipe = L.Clear
L.HistoryWipeTip = "Delete after playback"
L.HotSpot2 = "Calculator"
L.HotSpot3 = "Tiny Pad"
L.HotSpot4 = SHOW_TARGET_OF_TARGET_TEXT
L.HotSpot5 = FOCUS
L.HotSpot6 = WORLD_MAP
L.HotSpot7 = "Bags"
L.HotSpot8 = "Meters/Logs"
L.HotSpot9 = INSPECT
L.HotSpot10 = TRADE
L.HotSpot11 = WHISPER
L.HotSpot12 = FOLLOW
L.HUD = "HUD"

L.Ignore = IGNORE
L.Included = "Included"
L.Installed = "Installed"

L.Large = LARGE
--L.Left = "Left"
L.Leader = LEADER
L.LeftClick = "Left Click - %s"
L.Load = "Load"
L.Lock = LOCK
L.LockActiveChatTip = "Prevents selected channel switching back to General"
L.Loot = LOOT
L.Low = LOW

L.Magoo = "Magoo"
L.Menu = "Menu"
L.MenuDragHint = "Drag items (from bags, spell book etc.) to the menu space in the right hand 'tower'."
L.MenuPage1 = "Always open to page 1"
--L.MeterNotLoaded = "Unable load meter %s:"
L.MiniButtons = "Mini Buttons"
L.Miscellaneous = "Miscellaneous"
L.Money = MONEY
L.MouseLookCursor = "Look Cursor"
L.MouseLookCursorTip = "Show cursor in MouseLook mode"
L.MS = "%s ms" --MilliSeconds
L.MultiLine = "MultiLine"
L.MultiLineTip = "Multiple line edit box"

L.Name = NAME
L.Names = NAMES_LABEL
L.Never = NEVER
L.New = NEW
L.NewSettingsText = "%s: %s."
L.No = NO
L.Normal = PLAYER_DIFFICULTY1
L.NotCopied = "Not Copied"
L.NumButtons = "Buttons per row"

L.OnLeftClick = "On Left Click"
L.OnLeftClickTip = "Swaps FM MiniButton left/right click action: Open Menu/Open Config."
L.OORange = "Out-of-range"
L.Options = OPTIONS
L.Order = "Order"
L.OverBuffs = "Over buffs"

L.Page = "Page %s"
L.Party = PARTY
L.Playback = PLAYBACK
L.Player = PLAYER
L.PetBattleHide = "Hide in Pet Battle"
L.PetBattleHideTip = "Hide FauxMazzle during pet battles."
L.PM = "%s pm"
L.PortraitButton = "Button Style"
L.PortraitButtonTip = "Sets the FM MiniButton display: 3D/2D portrait or FM text."
L.PrintMoneyTip = "Show all money gained/lost in Loot frame otherwise looted money only"

L.QuestTrackerCollapse = "Collapse Tracker"
L.QuestTrackerCollapseTip = "Collapse the quest tracker when zoning"
L.QueueStatus = "QueueStatus"

L.RaidFrames = RAID_FRAMES_LABEL
L.Random = "Random"
L.Released = "RELEASED"
L.Reload = "Reload"
L.ReloadTip = "Reload the UI"
L.Reset = RESET
L.ResetTip = "Flush character settings and reload defaults."
L.Remove = REMOVE
L.RightClick = "Right Click - %s"
L.Role = ROLE
L.RoleIcons = "Role Icons"

L.Save = SAVE
L.Say = SAY
L.Scale = "Scale"
L.Select = LFG_LIST_SELECT
L.Settings = "%s Settings"
L.Skins = "Skins"
L.SkinsDailyTip = "Change skin once per day or every login if not checked"
L.SkinsRandomExcludeTip = "Random List %s"
L.SkinsRandomTip = "Select a skin at random when logging on"
L.SpecColors = "Color by spec."
L.Subgroup = "Subgroup"

L.TalkingHead = "Talking Head"
L.TalkingHeadTip = "Set the location to display the Talking Head frame (Ignore = default)"
L.Tank = TANK
L.Texts = "Texts"
L.Top = "Top"
L.TopLeft = "Top Left"
L.TopRight = "Top Right"
L.Totems = UNIT_NAME_ENEMY_TOTEMS
L.Trade = TRADE
L.Thresholds = "Thresholds"
L.Threat = "Threat"

L.UI = "UI"
L.Unused = UNUSED
L.Update = UPDATE
L.UpdateAll = "Update All %s"

L.Vertical = "Vertical"

L.Whisper = WHISPER
L.Whispers = "Whispers"

L.Yes = YES

-----------------------
--	Compounds     --
-----------------------
L.DeletePage = L.Delete.." "..L.Page
